@@ -8,6 +8,7 @@ import symengine as se
 from h5py import File
 from jitcdde import input as system_input
 
+from ....utils.stimulus import OrnsteinUhlenbeckProcess
 from ..builder.base.constants import EXC, INH, LAMBDA_SPEED
 from ..builder.base.network import Network, SingleCouplingExcitatoryInhibitoryNode
 from ..builder.base.neural_mass import NeuralMass
@@ -203,7 +204,7 @@ class ALNMass(NeuralMass):
     """
 
     name = "ALN neural mass model"
-    label = "ALN"
+    label = "ALNMass"
     # define python callback function name for table lookup (linear-nonlinear
     # approximation of Fokker-Planck equation)
     python_callbacks = ["firing_rate_lookup", "voltage_lookup", "tau_lookup"]
@@ -379,7 +380,7 @@ class ExcitatoryALNMass(ALNMass):
     """
 
     name = "ALN excitatory neural mass"
-    label = f"ALN{EXC}"
+    label = f"ALNMass{EXC}"
     num_state_variables = 7
     coupling_variables = {6: f"r_mean_{EXC}"}
     mass_type = EXC
@@ -421,6 +422,8 @@ class ExcitatoryALNMass(ALNMass):
         "lambda",
     ]
 
+    _noise_input = [OrnsteinUhlenbeckProcess(mu=0.4, sigma=0.0, tau=5.0)]
+
     @staticmethod
     def _rescale_strengths(params):
         """
@@ -581,7 +584,7 @@ class InhibitoryALNMass(ALNMass):
     """
 
     name = "ALN inhibitory neural mass"
-    label = f"ALN{INH}"
+    label = f"ALNMass{INH}"
     num_state_variables = 6
     coupling_variables = {5: f"r_mean_{INH}"}
     mass_type = INH
@@ -616,6 +619,8 @@ class InhibitoryALNMass(ALNMass):
         "lambda",
     ]
 
+    _noise_input = [OrnsteinUhlenbeckProcess(mu=0.3, sigma=0.0, tau=5.0)]
+
     @staticmethod
     def _rescale_strengths(params):
         """
@@ -785,6 +790,7 @@ class ALNNode(SingleCouplingExcitatoryInhibitoryNode):
     }
 
     default_output = f"r_mean_{EXC}"
+    output_vars = [f"r_mean_{EXC}", f"r_mean_{INH}", f"I_A_{EXC}"]
 
     def _rescale_connectivity(self):
         """
@@ -911,6 +917,7 @@ class ALNNetwork(Network):
     label = "ALNNet"
 
     sync_variables = ["network_exc_exc", "network_exc_exc_sq"]
+    output_vars = [f"r_mean_{EXC}", f"r_mean_{INH}", f"I_A_{EXC}"]
 
     def __init__(
         self,
@@ -1022,8 +1029,8 @@ class ALNNetwork(Network):
             + self._additive_coupling(
                 within_node_idx=coupling_var_idx,
                 symbol="network_exc_exc_sq",
-                # multiplier is connectivity again, then they'll be squared
-                connectivity_multiplier=self.connectivity,
+                # use squared connectivity
+                connectivity=self.connectivity * self.connectivity,
             )
             + super()._sync()
         )
