@@ -406,10 +406,10 @@ class SingleCouplingExcitatoryInhibitoryNode(Node):
         local_delays = params_dict.pop(NODE_DELAYS, None)
         if local_connectivity is not None and isinstance(local_connectivity, np.ndarray):
             assert local_connectivity.shape == self.connectivity.shape
-            self.connectivity = local_connectivity
+            self.connectivity = local_connectivity.astype(np.floating)
         if local_delays is not None and isinstance(local_delays, np.ndarray):
             assert local_delays.shape == self.delays.shape
-            self.delays = local_delays
+            self.delays = local_delays.astype(np.floating)
         super().update_params(params_dict)
 
     def _sync(self):
@@ -626,8 +626,8 @@ class Network(BackendIntegrator):
         nested_dict = {self.label: {}}
         for node in self:
             nested_dict[self.label].update(node.get_nested_params())
-        nested_dict[NETWORK_CONNECTIVITY] = self.connectivity
-        nested_dict[NETWORK_DELAYS] = self.delays
+        nested_dict[self.label][NETWORK_CONNECTIVITY] = self.connectivity
+        nested_dict[self.label][NETWORK_DELAYS] = self.delays
         return nested_dict
 
     def init_network(self, **kwargs):
@@ -666,10 +666,10 @@ class Network(BackendIntegrator):
                 self.nodes[node_index].update_params(node_params)
             elif NETWORK_CONNECTIVITY == node_key:
                 assert node_params.shape == self.connectivity.shape
-                self.connectivity = node_params
+                self.connectivity = node_params.astype(np.floating)
             elif NETWORK_DELAYS == node_key:
                 assert node_params.shape == self.delays.shape
-                self.delays = node_params
+                self.delays = node_params.astype(np.floating)
             else:
                 logging.warning(f"Not sure what to do with {node_key}...")
 
