@@ -201,10 +201,10 @@ def plot_brain(
     else:
         # some weird scaling of the color to a size
         def norm(what):
-            what = what.copy()
+            what = np.asarray(what.copy())
             if np.min(what) < np.max(what):
                 what -= np.min(what)
-                what /= np.max(what)
+                what = np.divide(what, np.max(what))
             return what
 
         node_size = list(np.exp((norm(color) + 2) * 2))
