@@ -19,11 +19,10 @@ class ModelInput:
 
     def __init__(self, num_iid=1, seed=None):
         """
-        :param num_iid: how many independent realisation of
-            the input we want - for constant inputs the array is just copied,
-            for noise this means independent realisation
+        :param num_iid: number of independent realisations of the input.
+            Deterministic inputs are just copied, noise inputs will produce independent realisations.
         :type num_iid: int
-        :param seed: optional seed for noise generator
+        :param seed: optional seed for random number generator
         :type seed: int|None
         """
         self.num_iid = num_iid
